{ TMMLabel-component version 1.0 - copyright  1996 by Alexander Meeder
  You can use this component to simulate 'hyperlinks' in your apps

  The following property's were added:
  LinkColor -> Color before label is clicked (default clBlue)
  FollowedColor -> Color after the label is clicked (default clRed)
  MouseSensitive -> if 'true' then the LinkColor is used when you enter label with the mouse
                    if 'false' then the LinkColor is permanently used until you clicked it
  IsClicked -> false until you clicked the label once, you can reset this value at runtime
}

unit mmlabel;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls;

type
  TMMLabel = class(TLabel)
  private
    NormalColor: TColor;
    FFollowedColor: TColor;
    FIsClicked: boolean;
    FLinkColor: TColor;
    FMouseSensitive: boolean;

    procedure SetFollowedColor(value: TColor);
    procedure SetIsClicked(value: boolean);
    procedure SetLinkColor(value: TColor);
    procedure SetMouseSensitive(value: boolean);
    procedure CMMouseEnter(var Message: TMessage); message CM_MOUSEENTER;
    procedure CMMouseLeave(var Message: TMessage); message CM_MOUSELEAVE;
  protected

  public
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
    procedure Loaded; override;
    procedure Click; override;
  published
    property FollowedColor: TColor read FFollowedColor write SetFollowedColor default clRed;
    property IsClicked: boolean read FIsClicked write SetIsClicked default false;
    property LinkColor: TColor read FLinkColor write SetLinkColor default clBlue;
    property MouseSensitive: boolean read FMouseSensitive write SetMouseSensitive default true;
  end;

procedure Register;

implementation

procedure TMMLabel.SetIsClicked(value: boolean);
begin
  if value <> FIsClicked then
  begin
    FIsClicked := value;
    if not FIsClicked then
    begin
      Font.Color := NormalColor;
      invalidate;
    end;
  end;
end;

procedure TMMLabel.SetFollowedColor(value: TColor);
begin
  if value <> FFollowedColor then
  begin
    FFollowedColor := value;
  end;
end;

procedure TMMLabel.SetLinkColor(value: TColor);
begin
  if value <> FLinkColor then
  begin
    FLinkColor := value;
  end;
end;

procedure TMMLabel.SetMouseSensitive(value: boolean);
begin
  if value <> FMouseSensitive then
  begin
    FMouseSensitive := value;
  end;
end;

procedure TMMLabel.CMMouseEnter(var Message: TMessage);
begin
  if (MouseSensitive) and not (IsClicked) then
  begin
    NormalColor := Font.Color;
    Font.Color := FLinkColor;
    invalidate;
  end;
end;

procedure TMMLabel.CMMouseLeave(var Message: TMessage);
begin
  if (MouseSensitive) and not (IsClicked) then
  begin
    Font.Color := NormalColor;
    invalidate;
  end;
end;

procedure TMMLabel.Click;
begin
  inherited Click;
  IsClicked := true;
  Font.Color := FFollowedColor;
  invalidate;
end;

procedure TMMLabel.Loaded;
begin
  inherited Loaded;
  if MouseSensitive then
     NormalColor := Font.Color
  else
  begin
    NormalColor := LinkColor;
    Font.Color := LinkColor;
  end;
end;

constructor TMMLabel.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  FIsClicked := false;
  FMouseSensitive := true;
  FFollowedColor := clRed;
  FLinkColor := clBlue;
  NormalColor := Font.Color;
  Transparent := true;
end;

destructor TMMLabel.Destroy;
begin
  inherited Destroy;
end;

procedure Register;
begin
  RegisterComponents('Meeder', [TMMLabel]);
end;

end.
